@@ -2,13 +2,13 @@
 // ex: set ft=php fenc=utf-8 sts=4 ts=4 sw=4 et nomod:
 //
 // BSD LICENSE
-// 
-// Copyright (c) 2014-2016, Michael Truog <mjtruog at gmail dot com>
+//
+// Copyright (c) 2014-2017, Michael Truog <mjtruog at gmail dot com>
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
-// 
+//
 //     * Redistributions of source code must retain the above copyright
 //       notice, this list of conditions and the following disclaimer.
 //     * Redistributions in binary form must reproduce the above copyright
@@ -21,7 +21,7 @@
 //     * The name of the author may not be used to endorse or promote
 //       products derived from this software without specific prior
 //       written permission
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 // CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 // INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
@@ -217,10 +217,10 @@ class API
         return $this->poll_request(null, false);
     }
 
-    public function forward_($command, $name, $request_info, $request,
+    public function forward_($request_type, $name, $request_info, $request,
                              $timeout, $priority, $trans_id, $pid)
     {
-        switch ($command)
+        switch ($request_type)
         {
             case API::$ASYNC:
                 $this->forward_async($name, $request_info, $request,
@@ -279,11 +279,11 @@ class API
         throw new ForwardSyncException();
     }
 
-    public function return_($command, $name, $pattern,
+    public function return_($request_type, $name, $pattern,
                             $response_info, $response,
                             $timeout, $trans_id, $pid)
     {
-        switch ($command)
+        switch ($request_type)
         {
             case API::$ASYNC:
                 $this->return_async($name, $pattern, $response_info, $response,
@@ -412,7 +412,7 @@ class API
         return $this->timeout_terminate;
     }
 
-    private function null_response($command, $name, $pattern,
+    private function null_response($request_type, $name, $pattern,
                                    $request_info, $request,
                                    $timeout, $priority, $trans_id, $pid)
     {
@@ -612,9 +612,18 @@ class API
                     else
                         throw new TerminateException($this->timeout_terminate);
                 case MESSAGE_REINIT:
-                    $i += $j; $j = 4;
-                    list(, $this->process_count) = unpack('L', substr($data,
-                                                                      $i, $j));
+                    $i += $j; $j = 4 + 4 + 4 + 1 + 1;
+                    $tmp = unpack('L3a/cb/Cc', substr($data, $i, $j));
+                    $this->process_count = $tmp['a1'];
+                    $this->timeout_async = $tmp['a2'];
+                    $this->timeout_sync = $tmp['a3'];
+                    $this->priority_default = $tmp['b'];
+                    $this->request_timeout_adjustment = ($tmp['c'] == 1);
+                    if ($this->request_timeout_adjustment)
+                    {
+                        $this->request_timer = microtime(true);
+                        $this->request_timeout = 0;
+                    }
                     $i += $j;
                     break;
                 case MESSAGE_KEEPALIVE:
@@ -830,12 +839,24 @@ class API
                     }
                     assert(false);
                 case MESSAGE_REINIT:
-                    $i += $j; $j = 4;
-                    list(, $this->process_count
-                         ) = unpack('L', substr($data, $i, $j));
+                    $i += $j; $j = 4 + 4 + 4 + 1 + 1;
+                    $tmp = unpack('L3a/cb/Cc', substr($data, $i, $j));
+                    $this->process_count = $tmp['a1'];
+                    $this->timeout_async = $tmp['a2'];
+                    $this->timeout_sync = $tmp['a3'];
+                    $this->priority_default = $tmp['b'];
+                    $this->request_timeout_adjustment = ($tmp['c'] == 1);
+                    if ($this->request_timeout_adjustment)
+                    {
+                        $this->request_timer = microtime(true);
+                        $this->request_timeout = 0;
+                    }
                     $i += $j; $j = 4;
                     if ($i == $data_size)
+                    {
+                        $data = '';
                         break;
+                    }
                     elseif ($i < $data_size)
                         continue 2;
                     else
@@ -845,7 +866,10 @@ class API
                         new \Erlang\OtpErlangAtom('keepalive')));
                     $i += $j; $j = 4;
                     if ($i == $data_size)
+                    {
+                        $data = '';
                         break;
+                    }
                     elseif ($i < $data_size)
                         continue 2;
                     else
@@ -888,7 +912,7 @@ class API
                 return false;
             if (count($result_read) == 0)
                 return true;
-    
+
             $data = $this->recv($data);
             $data_size = strlen($data);
             if ($data_size == 0)
@@ -929,11 +953,6 @@ class API
         return $result;
     }
 
-    public function request_http_qs_parse($request)
-    {
-        return $this->text_key_value_parse($request);
-    }
-
     public function info_key_value_parse($message_info)
     {
         return $this->text_key_value_parse($message_info);
@@ -946,25 +965,31 @@ class API
         fwrite($this->s, $data);
     }
 
-    private function recv($data)
+    private function recv($data_old)
     {
+        $data = '';
         if ($this->use_header)
         {
-            while (strlen($data) < 4)
+            $i = 0;
+            while ($i < 4)
             {
-                $fragment = fread($this->s, $this->size);
+                $fragment = fread($this->s, 4 - $i);
                 $data .= $fragment;
+                $i += strlen($fragment);
             }
-            list(, $total) = unpack('N', substr($data, 0, 4));
-            $data = substr($data, 4);
-            while (strlen($data) < $total)
+            list(, $total) = unpack('N', $data);
+            $data = $data_old;
+            $i = 0;
+            while ($i < $total)
             {
-                $fragment = fread($this->s, $this->size);
+                $fragment = fread($this->s, min($total - $i, $this->size));
                 $data .= $fragment;
+                $i += strlen($fragment);
             }
         }
         else
         {
+            $data = $data_old;
             $ready = true;
             while ($ready == true)
             {
