@@ -71,11 +71,7 @@
 -include_lib("cloudi_core/include/cloudi_service_children.hrl").
 -include("cloudi_http_cowboy_handler.hrl").
 
--ifdef(ERLANG_OTP_VERSION_16).
--type dict_proxy(_Key, _Value) :: dict().
--else.
 -type dict_proxy(Key, Value) :: dict:dict(Key, Value).
--endif.
 
 -record(websocket_state,
     {
@@ -475,9 +471,8 @@ websocket_init(_Transport, Req0,
                         error ->
                             ok;
                         {ok, Pattern, Functions} ->
-                            Parameters = cloudi_service:
-                                         service_name_parse(PathRawStr,
-                                                            Pattern),
+                            Parameters = cloudi_service_name:
+                                         parse(PathRawStr, Pattern),
                             websocket_subscriptions(Functions, Parameters,
                                                     Scope)
                     end
